@@ -1,6 +1,6 @@
 #-*- coding: utf-8 -*-
 
-# Copyright 2012 Calculate Ltd. http://www.calculate-linux.org
+# Copyright 2012-2013 Calculate Ltd. http://www.calculate-linux.org
 #
 #  Licensed under the Apache License, Version 2.0 (the "License");
 #  you may not use this file except in compliance with the License.
@@ -443,10 +443,10 @@ def get_Frame(client, sid, pid):
     """ get all messages, until type is not endFrame (or Error) """
     end_frame = 1
     while end_frame:
-        current_frame = client.service[0].get_frame(sid, pid)
+        current_frame = client.service[0].get_frame(sid, pid, "console")
         while current_frame in [None, [], ""]:
             time.sleep(float(client.frame_period))
-            current_frame = client.service[0].get_frame(sid, pid)
+            current_frame = client.service[0].get_frame(sid, pid, "console")
         for item in current_frame[0]:
             end_frame = get_message(client, item, sid, pid)
             
@@ -466,7 +466,7 @@ def get_entire_frame(client, pid):
         current_frame = client.service.get_entire_frame(sid, pid)
         while current_frame in [None, [], ""]:
             time.sleep(1)
-            current_frame = client.service.get_frame(sid, pid)
+            current_frame = client.service.get_frame(sid, pid, "console")
         for item in current_frame[0]:
             end_frame = get_message(client, item, sid, pid)
 
